Class: PlainDataObject

Inherits:
Object
  • Object
show all
Defined in:
lib/model/plain_data_object.rb

Overview

This source code is licensed under the license found in the LICENSE file in the root directory of this source tree.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(host, query_params, cookies, referer = nil, x_forwarded_for = nil, remote_address = nil, scheme = nil, request_uri = nil) ⇒ PlainDataObject

Returns a new instance of PlainDataObject.



12
13
14
15
16
17
18
19
20
21
22
23
# File 'lib/model/plain_data_object.rb', line 12

def initialize(host, query_params, cookies, referer = nil,
               x_forwarded_for = nil, remote_address = nil,
               scheme = nil, request_uri = nil)
  @host = host
  @query_params = query_params
  @cookies = cookies
  @referer = referer
  @x_forwarded_for = x_forwarded_for
  @remote_address = remote_address
  @scheme = scheme
  @request_uri = request_uri
end

Instance Attribute Details

#cookiesObject

Returns the value of attribute cookies.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def cookies
  @cookies
end

#hostObject

Returns the value of attribute host.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def host
  @host
end

#query_paramsObject

Returns the value of attribute query_params.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def query_params
  @query_params
end

#refererObject

Returns the value of attribute referer.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def referer
  @referer
end

#remote_addressObject

Returns the value of attribute remote_address.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def remote_address
  @remote_address
end

#request_uriObject

Returns the value of attribute request_uri.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def request_uri
  @request_uri
end

#schemeObject

Returns the value of attribute scheme.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def scheme
  @scheme
end

#x_forwarded_forObject

Returns the value of attribute x_forwarded_for.



8
9
10
# File 'lib/model/plain_data_object.rb', line 8

def x_forwarded_for
  @x_forwarded_for
end